<?php

namespace Eform\Filing\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Eform\Filing\Actions\FilingsAction;
use Eform\Filing\Http\Requests\FilingsActionRequest;
use Eform\Filing\Http\Resources\FilingsResource;
use Eform\Filing\Models\Filings;

/**
 * Admin web controller class.
 */
class FilingsActionController extends BaseController
{

    /**
     * Action controller function for filings.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(FilingsActionRequest $request, Filings $filings, $action)
    {
        try {
            $request = $request->all();
            $filings = FilingsAction::run($action, $filings, $request);

            $data = new FilingsResource($filings);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('filing::filings.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('filing/filings/' . $filings->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('filing/filings/' . $filings->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
