<?php

namespace Eform\Filing\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Eform\Filing\Http\Requests\FilingsActionsRequest;
use Eform\Filing\Actions\FilingsActions;

/**
 * Admin web controller class.
 */
class FilingsActionsController extends BaseController
{

    /**
     * Action controller function for filings.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(FilingsActionsRequest $request, $action)
    {
        try {
            $filings = FilingsActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('filing::filings.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('filing/filings/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('filing/filings/' . $action))
                ->redirect();
        }
    }
}
