<?php

namespace Eform\Filing\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Eform\Filing\Http\Resources\FilingResource;
use Eform\Filing\Http\Resources\FilingsCollection;
use Eform\Filing\Scopes\FilingsPublicScope;
use Eform\Filing\Models\Filings;

class FilingsPublicController extends BaseController
{

    /**
     * Show filings's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Filings::pushScope(new RequestScope())
            ->pushScope(new FilingsPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $filings = new FilingsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('filing::filings.names'))
            ->view('filing::public.filings.index')
            ->data(compact('filings', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show filings.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Filings::findBySlug($slug);
        $data = new FilingsResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('filing::filings.name'))
            ->view('filing::public.filings.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
