<?php

namespace Eform\Filing\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Eform\Filing\Events\FilingsAction as FilingsActionEvent;
use Eform\Filing\Notifications\FilingsAction as FilingsActionNotification;
use Litepie\Actions\Concerns\AsAction;

class FilingsAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the FilingsActionEvent.
     *
     * @param   FilingsActionEvent  $event
     * @return mixed
     */
    public function handle(FilingsActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $filings.
     *
     * @param   FilingsActionEvent  $event
     * @return void
     */
    public function create(FilingsActionEvent $event)
    {
        $client = $event->filings->client;
        Notification::send($client, new FilingsActionNotification($event));
    }

    /**
     * Handle the FilingsActionEvent as a listener.
     *
     * @param   FilingsActionEvent  $event
     * @return mixed
     */
    public function asListener(FilingsActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   FilingsActionEvent  $event
     * @return bool
     */
    private function isAllowed(FilingsActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
