<?php

namespace Eform\Filing\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Eform\Filing\Events\FilingsWorkflow as FilingsWorkflowEvent;
use Eform\Filing\Notifications\FilingsWorkflow as FilingsWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class FilingsWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(FilingsWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $filings is submitted.
     *
     * @param FilingsWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(FilingsWorkflowEvent $event)
    {
        $client = $event->filings->client;
        Notification::send($client, new FilingsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $filings is published.
     *
     * @param FilingsWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(FilingsWorkflowEvent $event)
    {
        $client = $event->filings->client;
        Notification::send($client, new FilingsWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $filings is approved.
     *
     * @param FilingsWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(FilingsWorkflowEvent $event)
    {
        $client = $event->filings->client;
        Notification::send($client, new FilingsWorkflowNotification($event));
    }

    /**
     * Handles the $filings workflow event as a listener.
     *
     * @param FilingsWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(FilingsWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
