<?php

namespace Eform\Filing\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Eform\Filing\Models\Filings;

class FilingsPolicy
{

    use FilingsAction;
    use FilingsExim;

    /**
     * Determine if the given user can view the filings.
     *
     * @param Authenticatable $user
     * @param Filings $filings
     *
     * @return bool
     */
    public function view(Authenticatable $user, Filings $filings)
    {
        if ($authUser->canDo('filing.filings.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $filings->is_owner;
    }

    /**
     * Determine if the given user can create a filings.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('filing.filings.create');
    }

    /**
     * Determine if the given user can update the given filings.
     *
     * @param Authenticatable $user
     * @param Filings $filings
     *
     * @return bool
     */
    public function update(Authenticatable $user, Filings $filings)
    {
        if ($user->canDo('filing.filings.edit') && $user->isAdmin()) {
            return true;
        }

        return $filings->is_owner;
    }

    /**
     * Determine if the given user can delete the given filings.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Filings $filings)
    {
        return $filings->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
